@@ -31,8 +31,6 @@
 
 static guint32 inhibitor_serial = 1;
 
-#define GSM_INHIBITOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GSM_TYPE_INHIBITOR, GsmInhibitorPrivate))
-
 struct GsmInhibitorPrivate
 {
         char *id;
@@ -41,7 +39,6 @@ struct GsmInhibitorPrivate
         char *client_id;
         char *reason;
         guint flags;
-        guint toplevel_xid;
         guint cookie;
         GDBusConnection *connection;
         GsmExportedInhibitor *skeleton;
@@ -56,7 +53,6 @@ enum {
         PROP_APP_ID,
         PROP_CLIENT_ID,
         PROP_FLAGS,
-        PROP_TOPLEVEL_XID,
         PROP_COOKIE
 };
 
@@ -66,7 +62,8 @@ enum {
 };
 static guint signals[LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE (GsmInhibitor, gsm_inhibitor, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_CODE (GsmInhibitor, gsm_inhibitor, G_TYPE_OBJECT,
+                         G_ADD_PRIVATE (GsmInhibitor))
 
 #define GSM_INHIBITOR_DBUS_IFACE "org.gnome.SessionManager.Inhibitor"
 
@@ -151,15 +148,6 @@ gsm_inhibitor_get_flags (GsmExportedInhibitor  *skeleton,
         return TRUE;
 }
 
-static gboolean
-gsm_inhibitor_get_toplevel_xid (GsmExportedInhibitor  *skeleton,
-                                GDBusMethodInvocation *invocation,
-                                GsmInhibitor          *inhibitor)
-{
-        gsm_exported_inhibitor_complete_get_toplevel_xid (skeleton, invocation, inhibitor->priv->toplevel_xid);
-        return TRUE;
-}
-
 static guint32
 get_next_inhibitor_serial (void)
 {
@@ -209,8 +197,6 @@ register_inhibitor (GsmInhibitor *inhibitor)
                           G_CALLBACK (gsm_inhibitor_get_flags), inhibitor);
         g_signal_connect (skeleton, "handle-get-reason",
                           G_CALLBACK (gsm_inhibitor_get_reason), inhibitor);
-        g_signal_connect (skeleton, "handle-get-toplevel-xid",
-                          G_CALLBACK (gsm_inhibitor_get_toplevel_xid), inhibitor);
 
         return TRUE;
 }
@@ -240,7 +226,7 @@ gsm_inhibitor_constructor (GType                  type,
 static void
 gsm_inhibitor_init (GsmInhibitor *inhibitor)
 {
-        inhibitor->priv = GSM_INHIBITOR_GET_PRIVATE (inhibitor);
+        inhibitor->priv = gsm_inhibitor_get_instance_private (inhibitor);
 }
 
 static void
@@ -350,18 +336,6 @@ gsm_inhibitor_set_flags (GsmInhibitor  *inhibitor,
         }
 }
 
-static void
-gsm_inhibitor_set_toplevel_xid (GsmInhibitor  *inhibitor,
-                                guint          xid)
-{
-        g_return_if_fail (GSM_IS_INHIBITOR (inhibitor));
-
-        if (inhibitor->priv->toplevel_xid != xid) {
-                inhibitor->priv->toplevel_xid = xid;
-                g_object_notify (G_OBJECT (inhibitor), "toplevel-xid");
-        }
-}
-
 const char *
 gsm_inhibitor_peek_bus_name (GsmInhibitor  *inhibitor)
 {
@@ -410,14 +384,6 @@ gsm_inhibitor_peek_flags (GsmInhibitor  *inhibitor)
         return inhibitor->priv->flags;
 }
 
-guint
-gsm_inhibitor_peek_toplevel_xid (GsmInhibitor  *inhibitor)
-{
-        g_return_val_if_fail (GSM_IS_INHIBITOR (inhibitor), 0);
-
-        return inhibitor->priv->toplevel_xid;
-}
-
 guint
 gsm_inhibitor_peek_cookie (GsmInhibitor  *inhibitor)
 {
@@ -455,9 +421,6 @@ gsm_inhibitor_set_property (GObject       *object,
         case PROP_COOKIE:
                 gsm_inhibitor_set_cookie (self, g_value_get_uint (value));
                 break;
-        case PROP_TOPLEVEL_XID:
-                gsm_inhibitor_set_toplevel_xid (self, g_value_get_uint (value));
-                break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
                 break;
@@ -493,9 +456,6 @@ gsm_inhibitor_get_property (GObject    *object,
         case PROP_COOKIE:
                 g_value_set_uint (value, self->priv->cookie);
                 break;
-        case PROP_TOPLEVEL_XID:
-                g_value_set_uint (value, self->priv->toplevel_xid);
-                break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
                 break;
@@ -582,15 +542,6 @@ gsm_inhibitor_class_init (GsmInhibitorClass *klass)
                                                             G_MAXINT,
                                                             0,
                                                             G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
-        g_object_class_install_property (object_class,
-                                         PROP_TOPLEVEL_XID,
-                                         g_param_spec_uint ("toplevel-xid",
-                                                            "toplevel-xid",
-                                                            "toplevel-xid",
-                                                            0,
-                                                            G_MAXINT,
-                                                            0,
-                                                            G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
         g_object_class_install_property (object_class,
                                          PROP_COOKIE,
                                          g_param_spec_uint ("cookie",
@@ -600,13 +551,10 @@ gsm_inhibitor_class_init (GsmInhibitorClass *klass)
                                                             G_MAXINT,
                                                             0,
                                                             G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
-
-        g_type_class_add_private (klass, sizeof (GsmInhibitorPrivate));
 }
 
 GsmInhibitor *
 gsm_inhibitor_new (const char    *app_id,
-                   guint          toplevel_xid,
                    guint          flags,
                    const char    *reason,
                    const char    *bus_name,
@@ -619,7 +567,6 @@ gsm_inhibitor_new (const char    *app_id,
                                   "reason", reason,
                                   "bus-name", bus_name,
                                   "flags", flags,
-                                  "toplevel-xid", toplevel_xid,
                                   "cookie", cookie,
                                   NULL);
 
