@@ -73,7 +73,6 @@ typedef GObject GsmSystemNull;
 typedef GObjectClass GsmSystemNullClass;
 
 static void do_nothing (void) { }
-static gboolean return_true (void) { return TRUE; }
 static gboolean return_false (void) { return FALSE; }
 
 static void
@@ -91,11 +90,9 @@ gsm_system_null_init_iface (GsmSystemInterface *iface)
         iface->suspend           = (void *) do_nothing;
         iface->hibernate         = (void *) do_nothing;
         iface->set_session_idle  = (void *) do_nothing;
-        iface->is_login_session  = (void *) return_true;
         iface->set_inhibitors    = (void *) do_nothing;
         iface->prepare_shutdown  = (void *) do_nothing;
         iface->complete_shutdown = (void *) do_nothing;
-        iface->is_last_session_for_user = (void *) return_false;
 }
 
 static void
@@ -216,18 +213,6 @@ gsm_system_set_inhibitors (GsmSystem        *system,
         GSM_SYSTEM_GET_IFACE (system)->set_inhibitors (system, flags);
 }
 
-gboolean
-gsm_system_is_login_session (GsmSystem *system)
-{
-        return GSM_SYSTEM_GET_IFACE (system)->is_login_session (system);
-}
-
-gboolean
-gsm_system_is_last_session_for_user (GsmSystem *system)
-{
-        return GSM_SYSTEM_GET_IFACE (system)->is_last_session_for_user (system);
-}
-
 /**
  * gsm_system_is_active:
  *
